@@ -1,26 +1,23 @@
 # Statistics Menu dialogs
 
-# last modified 13 Mar 05 by J. Fox
+# last modified 26 March 2008 by J. Fox
 
     # Variances menu
     
 twoVariancesFTest <- function(){
-##    if (!checkActiveDataSet()) return()
-##    if (!checkNumeric()) return()
-##    if (!checkTwoLevelFactors()) return()
-    initializeDialog(title="Two Variances F-Test")
+    initializeDialog(title=gettextRcmdr("Two Variances F-Test"))
     variablesFrame <- tkframe(top)
-    groupBox <- variableListBox(variablesFrame, TwoLevelFactors(), title="Groups (pick one)")
-    responseBox <- variableListBox(variablesFrame, Numeric(), title="Response Variable (pick one)")
+    groupBox <- variableListBox(variablesFrame, TwoLevelFactors(), title=gettextRcmdr("Groups (pick one)"))
+    responseBox <- variableListBox(variablesFrame, Numeric(), title=gettextRcmdr("Response Variable (pick one)"))
     onOK <- function(){
         group <- getSelection(groupBox)
         if (length(group) == 0) {
-            errorCondition(recall=twoVariancesFTest, message="You must select a groups variable.")
+            errorCondition(recall=twoVariancesFTest, message=gettextRcmdr("You must select a groups variable."))
             return()
             }
         response <- getSelection(responseBox)
         if (length(response) == 0) {
-            errorCondition(recall=twoVariancesFTest, message="You must select a response variable.")
+            errorCondition(recall=twoVariancesFTest, message=gettextRcmdr("You must select a response variable."))
             return()
             }
         alternative <- as.character(tclvalue(alternativeVariable))
@@ -37,14 +34,14 @@ twoVariancesFTest <- function(){
         }
     OKCancelHelp(helpSubject="var.test")
     radioButtons(name="alternative", buttons=c("twosided", "less", "greater"), values=c("two.sided", "less", "greater"),
-        labels=c("Two-sided", "Difference < 0", "Difference > 0"), title="Alternative Hypothesis")
+        labels=gettextRcmdr(c("Two-sided", "Difference < 0", "Difference > 0")), title=gettextRcmdr("Alternative Hypothesis"))
     confidenceFrame <- tkframe(top)
     confidenceLevel <- tclVar(".95")
-    confidenceField <- tkentry(confidenceFrame, width="6", textvariable=confidenceLevel)
-    tkgrid(getFrame(groupBox), tklabel(variablesFrame, text="    "), getFrame(responseBox), sticky="nw")
+    confidenceField <- ttkentry(confidenceFrame, width="6", textvariable=confidenceLevel)
+    tkgrid(getFrame(groupBox), labelRcmdr(variablesFrame, text="    "), getFrame(responseBox), sticky="nw")
     tkgrid(variablesFrame, sticky="w")
     groupsLabel(groupsBox=groupBox)
-    tkgrid(tklabel(confidenceFrame, text="Confidence Level:  ", fg="blue"), confidenceField, sticky="w")
+    tkgrid(labelRcmdr(confidenceFrame, text=gettextRcmdr("Confidence Level:  "), fg="blue"), confidenceField, sticky="w")
     tkgrid(alternativeFrame, sticky="w")
     tkgrid(confidenceFrame, sticky="w")
     tkgrid(buttonsFrame, sticky="w")
@@ -52,22 +49,19 @@ twoVariancesFTest <- function(){
     }
 
 BartlettTest <- function(){
-##    if (!checkActiveDataSet()) return()
-##    if (!checkNumeric()) return()
-##    if (!checkFactors()) return()
-    initializeDialog(title="Bartlett's Test")
+    initializeDialog(title=gettextRcmdr("Bartlett's Test"))
     variableFrame <- tkframe(top)
-    groupBox <- variableListBox(variableFrame, Factors(), title="Groups (pick one)")
-    responseBox <- variableListBox(variableFrame, Numeric(), title="Response Variable (pick one)")
+    groupBox <- variableListBox(variableFrame, Factors(), title=gettextRcmdr("Groups (pick one)"))
+    responseBox <- variableListBox(variableFrame, Numeric(), title=gettextRcmdr("Response Variable (pick one)"))
     onOK <- function(){
         group <- getSelection(groupBox)
         if (length(group) == 0) {
-            errorCondition(recall=BartlettTest, message="You must select a groups variable.")
+            errorCondition(recall=BartlettTest, message=gettextRcmdr("You must select a groups variable."))
             return()
             }
         response <- getSelection(responseBox)
         if (length(response) == 0) {
-            errorCondition(recall=BartlettTest, message="You must select a response variable.")
+            errorCondition(recall=BartlettTest, message=gettextRcmdr("You must select a response variable."))
             return()
             }
         closeDialog()
@@ -79,29 +73,27 @@ BartlettTest <- function(){
         tkfocus(CommanderWindow())
         }
     OKCancelHelp(helpSubject="bartlett.test")
-    tkgrid(getFrame(groupBox), tklabel(variableFrame, text="    "), getFrame(responseBox), sticky="nw")
+    tkgrid(getFrame(groupBox), labelRcmdr(variableFrame, text="    "), getFrame(responseBox), sticky="nw")
     tkgrid(variableFrame, sticky="w")
     tkgrid(buttonsFrame, sticky="w")
     dialogSuffix(rows=2, columns=1)
     }
 
 LeveneTest <- function(){
-##    if (!checkActiveDataSet()) return()
-##    if (!checkNumeric()) return()
-##    if (!checkFactors()) return()
-    initializeDialog(title="Levene's Test")
+    require("car")
+    initializeDialog(title=gettextRcmdr("Levene's Test"))
     variableFrame <- tkframe(top)
-    groupBox <- variableListBox(variableFrame, Factors(), title="Groups (pick one)")
-    responseBox <- variableListBox(variableFrame, Numeric(), title="Response Variable (pick one)")
+    groupBox <- variableListBox(variableFrame, Factors(), title=gettextRcmdr("Groups (pick one)"))
+    responseBox <- variableListBox(variableFrame, Numeric(), title=gettextRcmdr("Response Variable (pick one)"))
     onOK <- function(){
         group <- getSelection(groupBox)
         if (length(group) == 0) {
-            errorCondition(recall=LeveneTest, message="You must select a groups variable.")
+            errorCondition(recall=LeveneTest, message=gettextRcmdr("You must select a groups variable."))
             return()
             }
         response <- getSelection(responseBox)
         if (length(response) == 0) {
-            errorCondition(recall=LeveneTest, message="You must select a response variable.")
+            errorCondition(recall=LeveneTest, message=gettextRcmdr("You must select a response variable."))
             return()
             }
         closeDialog()
@@ -113,7 +105,7 @@ LeveneTest <- function(){
         tkfocus(CommanderWindow())
         }
     OKCancelHelp(helpSubject="levene.test")
-    tkgrid(getFrame(groupBox), tklabel(variableFrame, text="    "), getFrame(responseBox), sticky="nw")
+    tkgrid(getFrame(groupBox), labelRcmdr(variableFrame, text="    "), getFrame(responseBox), sticky="nw")
     tkgrid(variableFrame, sticky="w")
     tkgrid(buttonsFrame, sticky="w")
     dialogSuffix(rows=2, columns=1)
